#
# Specifies the name of the last variable considered
# before plotting
#
lastvar = "k"

#
# Specifies the columns to be plotted
# and its label (in grace format)
#
col_contents = [(1, "\\f{Symbol} <r>"), (2, "\\f{Symbol} <dr>"), (3, "U\\sl")]


#
# Specifies the grace format of the x axis
#
xlabel = "\\f{Times-Italic}P"
