#
# Specifies the name of the last variable considered
# before plotting
#
lastvar = "m"

#
# Specifies the columns to be plotted
# and its label (in grace format)
#
col_contents = [(1, 2, "\\f{Symbol}\\l{.15}r"), (3, 4, "\\f{Times-Italic}T")]


#
# Specifies the grace format of the x axis
#
xlabel = "\\f{Times-Italic}P"
